==> VariantFiltering_1.6.21.tar.gz: VariantFiltering/inst/doc/usingVariantFiltering.R <==
### R code from vignette source 'usingVariantFiltering.Rnw'

###################################################
### code chunk number 1: style
###################################################
BiocStyle::latex(use.unsrturl=FALSE)


###################################################
### code chunk number 2: <setup
###################################################
pdf.options(useDingbats=FALSE)
options(width=80)


###################################################
### code chunk number 3: usingVariantFiltering.Rnw:89-95
###################################################
library(VariantFiltering)

CEUvcf <- file.path(system.file("extdata", package="VariantFiltering"), "CEUtrio.vcf.bgz")
vfpar <- VariantFilteringParam(vcfFilenames=CEUvcf)
class(vfpar)
vfpar


###################################################
### code chunk number 4: usingVariantFiltering.Rnw:102-103
###################################################
args(VariantFilteringParam)


###################################################
### code chunk number 5: usingVariantFiltering.Rnw:116-119
###################################################
uind <- unrelatedIndividuals(vfpar)
class(uind)
uind


###################################################
### code chunk number 6: usingVariantFiltering.Rnw:130-131
###################################################
summary(uind)


###################################################
### code chunk number 7: usingVariantFiltering.Rnw:145-146
###################################################
summary(uind, method="bioc")


###################################################
### code chunk number 8: usingVariantFiltering.Rnw:152-154
###################################################
uindSO <- summary(uind, method="SOfull")
uindSO


###################################################
### code chunk number 9: usingVariantFiltering.Rnw:161-162
###################################################
uindSO[uindSO$Level == 6, ]


###################################################
### code chunk number 10: usingVariantFiltering.Rnw:167-168
###################################################
allVariants(uind)


###################################################
### code chunk number 11: displayedVariant
###################################################
path2bams <- file.path(system.file("extdata", package="VariantFiltering"),
                       paste0(samples(uind), ".subset.bam"))
bv <- BamViews(bamPaths=path2bams,
               bamSamples=DataFrame(row.names=samples(uind)))
bamFiles(uind) <- bv
bamFiles(uind)
plot(uind, what="rs6130959", sampleName="NA12892")


###################################################
### code chunk number 12: usingVariantFiltering.Rnw:204-209
###################################################
samples(uind)
samples(uind) <- c("NA12891", "NA12892")
uind
uindSO2sam <- summary(uind, method="SOfull")
uindSO2sam[uindSO2sam$Level == 6, ]


###################################################
### code chunk number 13: usingVariantFiltering.Rnw:215-217
###################################################
uind <- resetSamples(uind)
uind


###################################################
### code chunk number 14: usingVariantFiltering.Rnw:228-229
###################################################
filters(uind)


###################################################
### code chunk number 15: usingVariantFiltering.Rnw:235-236
###################################################
active(filters(uind))


###################################################
### code chunk number 16: usingVariantFiltering.Rnw:241-244
###################################################
active(filters(uind)) <- TRUE
active(filters(uind))
summary(uind)


###################################################
### code chunk number 17: usingVariantFiltering.Rnw:249-252
###################################################
active(filters(uind)) <- FALSE
active(filters(uind))["dbSNP"] <- TRUE
summary(uind)


###################################################
### code chunk number 18: usingVariantFiltering.Rnw:261-265
###################################################
cutoffs(uind)$SOterms <- "UTR_variant"
active(filters(uind))["SOterms"] <- TRUE
summary(uind)
summary(uind, method="SOfull")


###################################################
### code chunk number 19: usingVariantFiltering.Rnw:277-288
###################################################
startLost <- function(x) {
  mask <- start(allVariants(x, groupBy="nothing")$CDSLOC) == 1 &
          as.character(allVariants(x, groupBy="nothing")$REFCODON) == "ATG" &
          as.character(allVariants(x, groupBy="nothing")$VARCODON) != "ATG"
  mask
}
filters(uind)$startLost <- startLost
active(filters(uind)) <- FALSE
active(filters(uind))["startLost"] <- TRUE
active(filters(uind))
summary(uind)


###################################################
### code chunk number 20: usingVariantFiltering.Rnw:301-309
###################################################
active(filters(uind)) <- FALSE
MAFmask <- MAFpop(uind)
MAFmask
MAFpop(uind) <- !MAFmask
MAFpop(uind, "ASN_AFKG") <- TRUE
MAFpop(uind)
maxMAF(uind) <- 0.01
summary(uind)


###################################################
### code chunk number 21: usingVariantFiltering.Rnw:315-316
###################################################
filteredVariants(uind)


###################################################
### code chunk number 22: usingVariantFiltering.Rnw:327-330 (eval = FALSE)
###################################################
## CEUped <- file.path(system.file("extdata", package="VariantFiltering"),
##                     "CEUtrio.ped")
## param <- VariantFilteringParam(vcfFilenames=CEUvcf, pedFilename=CEUped)


###################################################
### code chunk number 23: reportvariants (eval = FALSE)
###################################################
## reportVariants(uind, type="csv", file="uind.csv")


###################################################
### code chunk number 24: info
###################################################
toLatex(sessionInfo())

==> VariantFiltering_1.8.6.tar.gz: VariantFiltering/inst/doc/usingVariantFiltering.R <==
### R code from vignette source 'usingVariantFiltering.Rnw'

###################################################
### code chunk number 1: style
###################################################
BiocStyle::latex(use.unsrturl=FALSE)


###################################################
### code chunk number 2: <setup
###################################################
pdf.options(useDingbats=FALSE)
options(width=80)


###################################################
### code chunk number 3: usingVariantFiltering.Rnw:89-95
###################################################
library(VariantFiltering)

CEUvcf <- file.path(system.file("extdata", package="VariantFiltering"), "CEUtrio.vcf.bgz")
vfpar <- VariantFilteringParam(vcfFilenames=CEUvcf)
class(vfpar)
vfpar


###################################################
### code chunk number 4: usingVariantFiltering.Rnw:102-103
###################################################
args(VariantFilteringParam)


###################################################
### code chunk number 5: usingVariantFiltering.Rnw:116-122
###################################################
if (VariantFiltering:::.getOS() == "windows") {
  uind <- readRDS(system.file("extdata", "uind.rds", package="VariantFiltering"))
  uind@inputParameters <- vfpar
  uind@filters <- filters(vfpar)
} else
  uind <- unrelatedIndividuals(vfpar)


###################################################
### code chunk number 6: usingVariantFiltering.Rnw:124-125 (eval = FALSE)
###################################################
## uind <- unrelatedIndividuals(vfpar)


###################################################
### code chunk number 7: usingVariantFiltering.Rnw:127-129
###################################################
class(uind)
uind


###################################################
### code chunk number 8: usingVariantFiltering.Rnw:140-141
###################################################
summary(uind)


###################################################
### code chunk number 9: usingVariantFiltering.Rnw:155-156
###################################################
summary(uind, method="bioc")


###################################################
### code chunk number 10: usingVariantFiltering.Rnw:162-164
###################################################
uindSO <- summary(uind, method="SOfull")
uindSO


###################################################
### code chunk number 11: usingVariantFiltering.Rnw:171-172
###################################################
uindSO[uindSO$Level == 6, ]


###################################################
### code chunk number 12: usingVariantFiltering.Rnw:177-178
###################################################
allVariants(uind)


###################################################
### code chunk number 13: displayedVariant
###################################################
path2bams <- file.path(system.file("extdata", package="VariantFiltering"),
                       paste0(samples(uind), ".subset.bam"))
bv <- BamViews(bamPaths=path2bams,
               bamSamples=DataFrame(row.names=samples(uind)))
bamFiles(uind) <- bv
bamFiles(uind)
plot(uind, what="rs6130959", sampleName="NA12892")


###################################################
### code chunk number 14: usingVariantFiltering.Rnw:214-219
###################################################
samples(uind)
samples(uind) <- c("NA12891", "NA12892")
uind
uindSO2sam <- summary(uind, method="SOfull")
uindSO2sam[uindSO2sam$Level == 6, ]


###################################################
### code chunk number 15: usingVariantFiltering.Rnw:225-227
###################################################
uind <- resetSamples(uind)
uind


###################################################
### code chunk number 16: usingVariantFiltering.Rnw:238-239
###################################################
filters(uind)


###################################################
### code chunk number 17: usingVariantFiltering.Rnw:245-246
###################################################
active(filters(uind))


###################################################
### code chunk number 18: usingVariantFiltering.Rnw:251-254
###################################################
active(filters(uind)) <- TRUE
active(filters(uind))
summary(uind)


###################################################
### code chunk number 19: usingVariantFiltering.Rnw:259-262
###################################################
active(filters(uind)) <- FALSE
active(filters(uind))["dbSNP"] <- TRUE
summary(uind)


###################################################
### code chunk number 20: usingVariantFiltering.Rnw:271-275
###################################################
cutoffs(uind)$SOterms <- "UTR_variant"
active(filters(uind))["SOterms"] <- TRUE
summary(uind)
summary(uind, method="SOfull")


###################################################
### code chunk number 21: usingVariantFiltering.Rnw:287-298
###################################################
startLost <- function(x) {
  mask <- start(allVariants(x, groupBy="nothing")$CDSLOC) == 1 &
          as.character(allVariants(x, groupBy="nothing")$REFCODON) == "ATG" &
          as.character(allVariants(x, groupBy="nothing")$VARCODON) != "ATG"
  mask
}
filters(uind)$startLost <- startLost
active(filters(uind)) <- FALSE
active(filters(uind))["startLost"] <- TRUE
active(filters(uind))
summary(uind)


###################################################
### code chunk number 22: usingVariantFiltering.Rnw:311-319
###################################################
active(filters(uind)) <- FALSE
MAFmask <- MAFpop(uind)
MAFmask
MAFpop(uind) <- !MAFmask
MAFpop(uind, "EAS_AFKG") <- TRUE
MAFpop(uind)
maxMAF(uind) <- 0.01
summary(uind)


###################################################
### code chunk number 23: usingVariantFiltering.Rnw:325-326
###################################################
filteredVariants(uind)


###################################################
### code chunk number 24: usingVariantFiltering.Rnw:337-340 (eval = FALSE)
###################################################
## CEUped <- file.path(system.file("extdata", package="VariantFiltering"),
##                     "CEUtrio.ped")
## param <- VariantFilteringParam(vcfFilenames=CEUvcf, pedFilename=CEUped)


###################################################
### code chunk number 25: reportvariants (eval = FALSE)
###################################################
## reportVariants(uind, type="csv", file="uind.csv")


###################################################
### code chunk number 26: info
###################################################
toLatex(sessionInfo())
